/*
 * DemosceneMusic - User.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.data;

import java.util.Collection;

/**
 * Data container for users of the website.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public interface User extends Base {

	/** Privilege level for site gods. */
	public static final int LEVEL_GOD = 100;

	/** Privilege level for normal users. */
	public static final int LEVEL_USER = 0;

	/**
	 * Returns the name of this user.
	 *
	 * @return The name of this user
	 */
	public String getName();

	/**
	 * Sets the name of this user.
	 *
	 * @param name
	 *            The name of this user
	 * @return This user
	 */
	public User setName(String name);

	/**
	 * Sets the password of this user.
	 *
	 * @param password
	 *            The new password of this user
	 * @return This user
	 */
	public User setPassword(String password);

	/**
	 * Sets the hash of the password of this user.
	 *
	 * @param passwordHash
	 *            The hash of the user’s password
	 * @return This user
	 */
	public User setPasswordHash(String passwordHash);

	/**
	 * Verifies the given password.
	 *
	 * @param password
	 *            The password to verify
	 * @return {@code true} if the given password matches the user’s password,
	 *         {@code false} otherwise
	 */
	public boolean verifyPassword(String password);

	/**
	 * Returns the privilege level of this user. 0 is the level of a normal user
	 * without any special privileges.
	 *
	 * @return The privilege level of this user
	 */
	public int getLevel();

	/**
	 * Sets the privilege level of this user.
	 *
	 * @param level
	 *            The privilege level of this user
	 * @return This user
	 */
	public User setLevel(int level);

	/**
	 * Returns all OpenIDs connected with this user.
	 *
	 * @return All OpenIDs connected with this user
	 */
	public Collection<String> getOpenIds();

	/**
	 * Sets all OpenIDs connected with this user.
	 *
	 * @param openIds
	 *            All OpenIDs connected with this user
	 * @return This user
	 */
	public User setOpenIds(Collection<String> openIds);

}
